@@ -812,8 +812,14 @@ class Pool(Endpoint):
         unmanaged: bool = False,
         arch: enums.Architecture = enums.Architecture.x86_64,
     ) -> models.Pool:
+        """
+        Create a worker pool
+
+        :param str name: Name of the worker-pool
+        """
         self.logger.debug("create worker pool")
         managed = not unmanaged
+
         return self._req_model(
             "POST",
             models.Pool,
@@ -823,6 +829,7 @@ class Pool(Endpoint):
                 "arch": arch,
                 "managed": managed,
                 "client_id": client_id,
+                "autoscale": None,
             },
         )
 
@@ -842,7 +849,7 @@ class Pool(Endpoint):
 
         return config
 
-    def shutdown(self, name: str, *, now: bool = False) -> models.Pool:
+    def shutdown(self, name: str, *, now: bool = False) -> responses.BoolResult:
         expanded_name = self._disambiguate(
             "name", name, lambda x: False, lambda: [x.name for x in self.list()]
         )
@@ -850,7 +857,7 @@ class Pool(Endpoint):
         self.logger.debug("shutdown worker pool: %s (now: %s)", expanded_name, now)
         return self._req_model(
             "DELETE",
-            models.Pool,
+            responses.BoolResult,
             json_data={"name": expanded_name, "now": now},
         )
 
@@ -1012,7 +1019,7 @@ class Scaleset(Endpoint):
 
     def shutdown(
         self, scaleset_id: UUID_EXPANSION, *, now: bool = False
-    ) -> models.Scaleset:
+    ) -> responses.BoolResult:
         scaleset_id_expanded = self._disambiguate_uuid(
             "scaleset_id",
             scaleset_id,
@@ -1022,7 +1029,7 @@ class Scaleset(Endpoint):
         self.logger.debug("shutdown scaleset: %s (now: %s)", scaleset_id_expanded, now)
         return self._req_model(
             "DELETE",
-            models.Scaleset,
+            responses.BoolResult,
             json_data={"scaleset_id": scaleset_id_expanded, "now": now},
         )
 
@@ -1283,51 +1290,58 @@ class Onefuzz:
 
         return data
 
-    def reset(self, everything: bool = False) -> None:
-        """
-        Resets onefuzz.  Stops all jobs, notifications, and repro VMs.
-        Specifying 'everything' will delete all containers, pools, and managed
-        scalesets.
-        """
-        message = ["Confirm stopping *all* running jobs"]
-        if everything:
-            message += ["AND deleting *ALL* fuzzing related data"]
-        message += ["(specify y or n): "]
-
+    def _user_confirmation(self, message: str) -> bool:
         answer: Optional[str] = None
         while answer not in ["y", "n"]:
-            answer = input(" ".join(message)).strip()
+            answer = input(message).strip()
 
         if answer == "n":
             self.logger.info("not stopping")
-            return
+            return False
+        return True
 
-        self.logger.info("stopping all interactions")
+    def _delete_components(
+        self,
+        containers: bool = False,
+        jobs: bool = False,
+        notifications: bool = False,
+        pools: bool = False,
+        repros: bool = False,
+        scalesets: bool = False,
+        tasks: bool = False,
+    ) -> None:
+        if jobs:
+            for job in self.jobs.list():
+                self.logger.info("stopping job %s", job.job_id)
+                self.jobs.delete(job.job_id)
 
-        for job in self.jobs.list():
-            self.logger.info("stopping job %s", job.job_id)
-            self.jobs.delete(job.job_id)
+        if tasks:
+            for task in self.tasks.list():
+                self.logger.info("stopping task %s", task.task_id)
+                self.tasks.delete(task.task_id)
 
-        for task in self.tasks.list():
-            self.logger.info("stopping task %s", task.task_id)
-            self.tasks.delete(task.task_id)
+        if notifications:
+            for notification in self.notifications.list():
+                self.logger.info(
+                    "stopping notification %s", notification.notification_id
+                )
+                self.notifications.delete(notification.notification_id)
 
-        for notification in self.notifications.list():
-            self.logger.info("stopping notification %s", notification.notification_id)
-            self.notifications.delete(notification.notification_id)
+        if repros:
+            for vm in self.repro.list():
+                self.repro.delete(str(vm.vm_id))
 
-        for vm in self.repro.list():
-            self.repro.delete(str(vm.vm_id))
-
-        if everything:
+        if pools:
             for pool in self.pools.list():
                 self.logger.info("stopping pool: %s", pool.name)
                 self.pools.shutdown(pool.name, now=True)
 
+        if scalesets:
             for scaleset in self.scalesets.list():
                 self.logger.info("stopping scaleset: %s", scaleset.scaleset_id)
                 self.scalesets.shutdown(scaleset.scaleset_id, now=True)
 
+        if containers:
             for container in self.containers.list():
                 if (
                     container.metadata
@@ -1348,6 +1362,75 @@ class Onefuzz:
                     self.logger.info("removing container: %s", container.name)
                     self.containers.delete(container.name)
 
+    def reset(
+        self,
+        containers: bool = False,
+        everything: bool = False,
+        jobs: bool = False,
+        notifications: bool = False,
+        pools: bool = False,
+        repros: bool = False,
+        scalesets: bool = False,
+        tasks: bool = False,
+        yes: bool = False,
+    ) -> None:
+        """
+        Resets onefuzz. Stops all jobs, notifications, and repro VMs.
+        Specifying 'everything' will delete all containers, pools, and managed
+        scalesets.
+
+        :param bool containers: Delete all the containers.
+        :param bool everything: Delete all containers, pools and managed scalesets.
+        :param bool jobs: Stop all jobs.
+        :param bool notifications: Stop all notifications.
+        :param bool pools: Delete all pools.
+        :param bool repros: Delete all repro vms.
+        :param bool scalesets: Delete all managed scalesets.
+        :param bool tasks: Stop all tasks.
+        :param bool yes: Ignoring to specify "y" in prompt.
+        """
+
+        if everything:
+            containers, jobs, pools, notifications, repros, scalesets, tasks = (
+                True,
+                True,
+                True,
+                True,
+                True,
+                True,
+                True,
+            )
+        elif not any(
+            [containers, jobs, pools, notifications, repros, scalesets, tasks]
+        ):
+            jobs, notifications, repros, tasks = True, True, True, True
+
+        if containers and not (tasks or jobs):
+            raise Exception("Resetting containers requires resetting jobs or tasks")
+
+        to_delete = []
+        argument_str = {
+            "jobs",
+            "tasks",
+            "notifications",
+            "pools",
+            "scalesets",
+            "repros",
+            "containers",
+        }
+        for k, v in locals().items():
+            if k in argument_str and v:
+                to_delete.append(k)
+        message = "Confirm stopping %s (specify y or n): " % (
+            ", ".join(sorted(to_delete))
+        )
+        if not yes and not self._user_confirmation(message):
+            return
+
+        self._delete_components(
+            containers, jobs, pools, notifications, repros, scalesets, tasks
+        )
+
 
 from .debug import Debug  # noqa: E402
 from .status.cmd import Status  # noqa: E402
